@@ -1,4 +1,3 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import,unused-argument,super-init-not-called
 """
 Main interface for outposts service client
 
@@ -45,7 +44,7 @@ class Exceptions:
 
 class OutpostsClient:
     """
-    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client)
+    [Outposts.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client)
     """
 
     meta: ClientMeta
@@ -53,7 +52,7 @@ class OutpostsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.can_paginate)
         """
 
     def create_outpost(
@@ -63,19 +62,20 @@ class OutpostsClient:
         Description: str = None,
         AvailabilityZone: str = None,
         AvailabilityZoneId: str = None,
+        Tags: Dict[str, str] = None,
     ) -> CreateOutpostOutputTypeDef:
         """
-        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.create_outpost)
+        [Client.create_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.create_outpost)
         """
 
     def delete_outpost(self, OutpostId: str) -> Dict[str, Any]:
         """
-        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.delete_outpost)
+        [Client.delete_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.delete_outpost)
         """
 
     def delete_site(self, SiteId: str) -> Dict[str, Any]:
         """
-        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.delete_site)
+        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.delete_site)
         """
 
     def generate_presigned_url(
@@ -86,29 +86,29 @@ class OutpostsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.generate_presigned_url)
         """
 
     def get_outpost(self, OutpostId: str) -> GetOutpostOutputTypeDef:
         """
-        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.get_outpost)
+        [Client.get_outpost documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.get_outpost)
         """
 
     def get_outpost_instance_types(
         self, OutpostId: str, NextToken: str = None, MaxResults: int = None
     ) -> GetOutpostInstanceTypesOutputTypeDef:
         """
-        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
+        [Client.get_outpost_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.get_outpost_instance_types)
         """
 
     def list_outposts(
         self, NextToken: str = None, MaxResults: int = None
     ) -> ListOutpostsOutputTypeDef:
         """
-        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.list_outposts)
+        [Client.list_outposts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.list_outposts)
         """
 
     def list_sites(self, NextToken: str = None, MaxResults: int = None) -> ListSitesOutputTypeDef:
         """
-        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.23/reference/services/outposts.html#Outposts.Client.list_sites)
+        [Client.list_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.26/reference/services/outposts.html#Outposts.Client.list_sites)
         """
